import React, { Suspense } from 'react';
import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import { Toaster } from 'react-hot-toast';
import { HelmetProvider } from 'react-helmet-async';
import ErrorBoundary from './components/ErrorBoundary';
import Navbar from './components/Navbar';
import Footer from './components/Footer';
import LoadingSpinner from './components/LoadingSpinner';

// Lazy loaded pages
const HomePage = React.lazy(() => import('./pages/HomePage'));
const CategoryPage = React.lazy(() => import('./pages/CategoryPage'));
const MediaDetailPage = React.lazy(() => import('./pages/MediaDetailPage'));
const SearchPage = React.lazy(() => import('./pages/SearchPage'));
const MapPage = React.lazy(() => import('./pages/MapPage'));
const AboutPage = React.lazy(() => import('./pages/AboutPage'));
const TermsPage = React.lazy(() => import('./pages/TermsPage'));
const AdminLoginPage = React.lazy(() => import('./pages/AdminLoginPage'));
const AdminDashboardPage = React.lazy(() => import('./pages/AdminDashboardPage'));
const AdminMediaFormPage = React.lazy(() => import('./pages/AdminMediaFormPage'));

function App() {
  return (
    <HelmetProvider>
      <ErrorBoundary>
        <Router>
          <div className="flex flex-col min-h-screen bg-slate-900 text-gray-800">
            <Navbar />
            
            <main className="flex-grow">
              <Suspense fallback={<LoadingSpinner />}>
                <Routes>
                  <Route path="/" element={<HomePage />} />
                  <Route path="/kategori/:slug" element={<CategoryPage />} />
                  {/* SEO dostu slug'lar ve ID ile erişim */}
                  <Route path="/medya/:id" element={<MediaDetailPage />} />
                  <Route path="/arama" element={<SearchPage />} />
                  <Route path="/harita" element={<MapPage />} />
                  <Route path="/hakkimizda" element={<AboutPage />} />
                  <Route path="/kullanici-sozlesmesi" element={<TermsPage />} />
                  <Route path="/admin/login" element={<AdminLoginPage />} />
                  <Route path="/admin/dashboard" element={<AdminDashboardPage />} />
                  <Route path="/admin/media/new" element={<AdminMediaFormPage />} />
                  <Route path="/admin/media/edit/:id" element={<AdminMediaFormPage />} />
                  <Route path="*" element={
                    <div className="min-h-screen flex items-center justify-center">
                      <div className="text-center">
                        <h1 className="text-4xl font-bold text-white mb-4">404</h1>
                        <p className="text-gray-300 mb-6">Aradığınız sayfa bulunamadı.</p>
                        <a href="/" className="bg-red-500 hover:bg-red-600 text-white px-6 py-2 rounded-full transition-colors">
                          Ana Sayfaya Dön
                        </a>
                      </div>
                    </div>
                  } />
                </Routes>
              </Suspense>
            </main>
            
            <Footer />
            <Toaster position="top-right" />
          </div>
        </Router>
      </ErrorBoundary>
    </HelmetProvider>
  );
}

export default App;